import { select, scaleLinear,max,scaleBand, axisBottom,axisLeft } from 'd3';

import {colorLegend} from './colorLegend'

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render= data=>{
  
const margin= {top: 30, right:20, bottom:20, left:70}
const innerWidth= width-margin.left-margin.right;
const innerHeight=height-margin.top-margin.bottom;

const xValue=d=>d.timestamp;
const yValue=d=>d.value;

const colorValue= d=>d.telescope;

// now for the scales
const xscale= d3.scaleTime()
.domain(d3.extent(data, xValue))
.range([0, innerWidth])
.nice() 

const colorScale = d3.scaleOrdinal(d3.schemeCategory10)

const yscale= d3.scaleLinear()
.domain(d3.extent(data, yValue))
.range([innerHeight,0])
.nice()
// now for the axis

const g= svg.append('g')
.attr('transform',`translate(${margin.left},${margin.top})`)

const xAxis= d3.axisBottom(xscale)
.tickSize((-innerHeight))
  
const yAxis= d3.axisLeft(yscale)
.tickSize((-innerWidth))

const xAxisG= g.append('g')
.call(xAxis)
.attr('transform',`translate(0,${innerHeight})`)


xAxisG.select('.domain').remove();
 
const yAxisG=g.append('g')
.call(yAxis)
yAxisG.selectAll('.domain').remove();
  //now for the line
const lineGenerator= d3.line()
.x(d=>xscale(xValue(d)))
.y(d=>yscale(yValue(d)))
.curve(d3.curveBasis)

const nested= d3.nest()
.key(colorValue)
.entries(data)

colorScale.domain(nested.map(function(d){return d.key}))

g.selectAll('.line-path').data(nested)
.enter().append('path')
.attr('class','line-path')
.attr('d',d=>lineGenerator(d.values))  
.attr('stroke',function(d){return colorScale(d.key)})
console.log(nested)
  
svg.append('g')
.attr('transform', `translate(180,150)`)
.call(colorLegend, {
colorScale,
circleRadius: 30,
spacing: 80,
textOffset: 40});
}

// first check the data is clean
d3.csv('SOTWeekly1.csv')
.then(function(data){
data.forEach(function(d){
d.value=+d.value;
d.timestamp= new Date(d.timestamp);  
 }) 
console.log(data)
render(data);
})

